bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift A ## 9. Aventiure
___________________________________________________ #### <Wie Sifrit ze Wormz gesant wart>
| ### o si gevaren waren volle niun tage ### do sprach von Trony Hagne nv hoeret waz ich sage ### wir sumen vns mit den mere ze Wormez an den Rin ### iwer boten solden nv ze Bvrgonden sin
###### 497 | ### Do sprach kvnich Gvnther ir habet war geseit ### vns were ze der verte niemen so bereit ### als ir friunt Hagne nv ritet in min lant ### vnser hovereise tuot in nieman baz bechant
###### 498 | ### Nv bitet Sifriden fueren die boeschaft [21a] ### der kan si wol gewerben mit ellenhafter kraft ### verseit er iv die reise ir svlt mit guoten siten ### durch iwer swester liebe der ferte in friuntlichen biten
###### 499 | ### Er sande nach dem rechen der kom do man in vant ### er sprach sit wir nahen heim in miniv lant ### so sold ich boten senden der lieben swester min ### vnd ovch miner mvter daz wir nahen an den Rin
###### 500 | ### Er sprac ir sult riten durch den willen min ### vnd ovch durch Kriemhilde daz schoene magedin ### daz ez mit mir verdiene div herliche meit ### do daz ehorte Sifrit do was der reke vil <bereit>
###### 501 | ### Enbietet swaz ir wellet des niht verdaget ### ich wil ez werben gerne durch die schoene maget ### zwiv sol ich die verzihen die ich in hercen han ### durch si swaz ir gebietet daz ist allez getan
###### 502 | ### So saget voten der richen kvnigen ### daz wir an dirre verte hohes muotes sin ### lat wizzen mine bruoder wie wir geworben han ### ir sult ovch vnser frivnde disiv mere horen lan
###### 503 | ### Mine schoene swester svlt ir niht verdagen ### ir svlt ir Brunhilde vnd minen dienest sagen ### vnd ovch dem gesinde vnd allen minen man ### darnach ie ranch min herze wol ich daz <verendet> han
###### 504 | ### Vnd saget Ortwine dem lieben neuen min ### daz er heize rihten sidel an den Rin ### vn– ander mine mage die sol man wizzen lan ### ich wil mit Prunhilde groz hochgecite han
###### 505 | ### Vnd saget miner swester so si habe vernomen ### daz ich mit minen gesten si ce lande komen ### daz si wol enphahe die truotine min ### daz wil ich immer diende umbe Kriemhilde sin
###### 506 | ### Sifrit der herre balde urlop nam ### vrovwen Prunhilde als im daz wol gezam ### vnd zallem ir gesinde do reit er an den Rin ### ez enkvnde in dirre werlde ein bote beser niht gesin
###### 507 | ### Mit vier vnd zweinzech reken ze Wormz er do reit ### des chvniges kom er ane do daz wart geseit ### allez daz gesinde muote iamers not ### si vorhten daz ir herre dort beliben were tot
###### 508 | ### Si erbeizten vont den rossen hohe stuont ir muot ### schiere chom in Giselher der iunge kvnich guot ### vnd Gernot sin bruoder wie balde er do sprach ### do er den kunich Gunther niht bi Sifride sach
###### 509 | ### Sit willechomen her Sifrit ir sult mich wizzen lan ### war ir minen bruoder den kvnich habet getan ### Prûnhilde sterke in wæn vns habe benomen ### so <wert> ir hohiu minne vns ze grozen schaden chomen
###### 510 | ### Die angest lat beliben iv und den magen sin ### enbivtet sinen dienst der hergeselle min ### den lie ich wol gesunden er hat mich iv gesant [21b] ### daz ich sin bote were mit mæren her in iwer lant
###### 511 | ### Ir svlt daz <ahten> schiere swie so daz gesehe ### daz ich die kuneginne vnd iwer swester sehe ### die sol ich lazen horen <waz> in enboten hat ### Gvnther vnd Prunhilt ir dinch in beiden hohe stat
###### 512 | ### Do sprach der iunge Giselher da svlt ir zuo in gan ### da habet ir miner swester liebe an getan ### si treit vil michel sorge vmbe den bruooder min ### diu meit sihet iu gerne des wil ich iwr burge sin
###### 513 | ### Do sprach der herre Sifrit swa ich ir dienen kan ### daz sol willeclichen mit triwen sin getan ### wer seit nu den frowen daz ich wil dar gan ### des wart do bote Giselher der vil wetliche man
###### 514 | ### Giselher der ivnge zuo siner mvoter sprach ### vnd ovch zuo siner swester da er si beide sach ### vns ist komen Sifrit der helt vz Niderlant ### in hat min bruoder Gvrnther her ze Rine gesant
###### 515 | ### Er bringet vns die mere wiez vmbe den kvnich ste ### nu sult ir im erlovben daz er ze hove ge ### er seit div rehten mere her von Islant ### noch was den edelen frowen michel truren bechant
###### 516 | ### Si sprungen nach ir wete vnd leit sich <an> ### si baten Syfriden hin ze hove gan ### daz tet er willeclichen wan er si gerne sach ### Criemhilt div edele zuo im vil guetlichen sprach
###### 517 | ### Sit willekomen <her> Sifrit riter lobelich ### wa ist min bruoder Gunther der edel chvnich rich ### von Prunhilde sterke den wæne wir han verlorn ### owe mir armer meide daz ich zer welde ie wart geborn
###### 518 | ### Do sprach der riter kuene gebet mir botenbrot ### ir vil schoene vrovwen weint ane not ### ich lie in wol gesvnden daz tuon ich iv bechant ### er hat mich iv beiden miten meren her gesant
###### 519 | ### Mit frivntlicher liebe vil edel kvnegin ### enbivtet iv ir dienst er vnd div wine sin ### vnd lat iwer weinen si wellent schiere komen ### si hete in manigen ziten so lieber mere nilht vernomen
###### 520 | ### Si bat <den> boten sicen des was er vil bereit ### do sprach div minnecliche mir were niht ze leit ### ob ich ce boten miete iv geben solde min golt ### darzuo sit ir ze riche ich wil iv sust wesen holt
###### 521 | ### Ob ich nu eine hete sprach er drizech lant ### so enphieng ich doch gerne gabe vz iwer hant ### do sprach div tvgentriche so sol ez sin getan ### si hiez ir kamerere nach der boten miete gan
###### 522 | ### Vier vnd zweinzech bovge mit gesteine guot ### gap si im ze miete so stvont des heldes muot ### er woldez niht behalten er gab ez sa cehant ### ir vil schoenen meiden die er ze kemnenaten vant
###### 523 | ### Ir mvoter bot ir dienst in vil guetlichen an ### ich sol ivch sagen mere sprach der kuene man [22a] ### wes iuch der kvnich bittet so er kvmet an den Rin ### ob ir daz fruewe leistet er welle iv immer wæge sin
###### 524 | ### Sine riche geste horte ich in gerne ### daz ir die wol enphahet vnd sult in des gewern ### daz ir gen ime ritet fur <Wormez> uf den sant ### des sit ir von dem kvnige mit guoten triwen gemant
###### 525 | ### Do sprach div minnecliche des bin ich bereit ### swaz ich im kan dienen daz ist vnuerseit ### mit frivntlichen triwen so sol ez sin getan ### do merte sich ir varwe die si vor liebe gewan
###### 526 | ### Ez wart nie bote enphangen deheins fursten baz ### getorste si in han <kvsset> daz hete si ane haz ### anders minneclichen er von der vrowen schiet ### do taten die Burgonden als in der bote geriet
###### 527 | ### Der palas vnd die wende was allez vber al ### gecieret gen den gesten der Gvnthers sal ### wart vil wol becimbert durch manigen <fremeden> man ### disiu starke hochgecit huop sich vil frolichen han
###### 528 | ### Do riten allenthalben die wege durch daz lant ### der drier kvnige nmage hete man besant ### daz si den solden warten di in da solden komen ### da wart uz der valde richer wate vil genomen
###### 529 | ### Do seite man div mere daz man riten sach ### Prunhilde vrivnde do huop sich vngemach ### von des volches krefte in Burgonden lant ### hei waz man kuener degne da ce beiden siten vant
###### 530 | ### Dar komen do die reken vnd hiezen tragen dar ### herliche setele von roten golde gar ### die die vrowen <solden> riten ze Wormz an den Rin ### bezer phertgereite chvnde nimmer gesin
###### 531 | ### Hei waz da liehtes goldes von den moren schein ### in luhte von den zomen vil manich edel stein ### die guldinen schamel ob liehtem phelle guot ### die brahte man den frowen si waren frolich gemvot
###### 532 | ### Sehs vnd ahcech vrovwen sach man fur gan ### die gebende truogen zuo Kriemhilde gan ### chomen die vil schoene vnd truogen richiv kleit ### dar kom ovch wol geciert vil wetlichiv meit
###### 533 | ### Si trvgen riche phelle die <besten> die man vant ### vor den vremden reken so manic guot gewant ### daz ir schoenen varwe ce rehte wol gezam ### er were in swachen muote der ir deheiner werde gram
###### 534 | ### Von dobel vnd uon harme vil chleider man da vant ### da wart vil wol gecieret manic arm vnd hant ### mit pogen ob den siden di si solden tragen ### iv enkvnde dice fliezen ze ende niemnen gesagen
###### 535 | ### Vil manigen gurtel spæhe rich vnde lanc ### vber liehtiv kleider manich hant do swanc ### vf edel roeke ferrans von pfelle vz Arabi ### den edeln iunchfrowen was vil hoher vrovden bi [22b]
###### 536 | ### Ez wart in furgespenge manich schoe meit ### genet vil minnecliche ez mohte ir wesen leit ### der ir liehtiv varwe niht luhte gen der <wat> ### so schoenes ingesindes nv niht kvniges kvnne hat
###### 537 | ### Do die minnechlichen nv truogevn ir gewant ### di si da fueren solden die komen dar zehant ### der hoch gemuoten rechen ein vil michel kraft ### man truoch ovch dar mit schilden manigen eschinen schaft

<<< Übersicht <<< vorige Seite nächste Seite >>>